==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RouteSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RouteSpecBuilder extends io.fabric8.openshift.api.model.RouteSpecFluentImpl<io.fabric8.openshift.api.model.RouteSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RouteSpec,io.fabric8.openshift.api.model.RouteSpecBuilder>{
  public RouteSpecBuilder() {
    this(false);
  }
  public RouteSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new RouteSpec(), validationEnabled);
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RouteSpec(), validationEnabled);
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpecFluent<?> fluent,io.fabric8.openshift.api.model.RouteSpec instance) {
    this(fluent, instance, false);
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpecFluent<?> fluent,io.fabric8.openshift.api.model.RouteSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlternateBackends(instance.getAlternateBackends()); 
    fluent.withHost(instance.getHost()); 
    fluent.withPath(instance.getPath()); 
    fluent.withPort(instance.getPort()); 
    fluent.withSubdomain(instance.getSubdomain()); 
    fluent.withTls(instance.getTls()); 
    fluent.withTo(instance.getTo()); 
    fluent.withWildcardPolicy(instance.getWildcardPolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpec instance) {
    this(instance,false);
  }
  public RouteSpecBuilder(io.fabric8.openshift.api.model.RouteSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlternateBackends(instance.getAlternateBackends()); 
    this.withHost(instance.getHost()); 
    this.withPath(instance.getPath()); 
    this.withPort(instance.getPort()); 
    this.withSubdomain(instance.getSubdomain()); 
    this.withTls(instance.getTls()); 
    this.withTo(instance.getTo()); 
    this.withWildcardPolicy(instance.getWildcardPolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RouteSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RouteSpec build() {
    RouteSpec buildable = new RouteSpec(fluent.getAlternateBackends(),fluent.getHost(),fluent.getPath(),fluent.getPort(),fluent.getSubdomain(),fluent.getTls(),fluent.getTo(),fluent.getWildcardPolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RouteSpecBuilder that = (RouteSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.4.0-sources.jar: io/fabric8/openshift/api/model/RouteSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RouteSpecBuilder extends RouteSpecFluentImpl<RouteSpecBuilder> implements VisitableBuilder<RouteSpec,RouteSpecBuilder>{
  public RouteSpecBuilder() {
    this(false);
  }
  public RouteSpecBuilder(Boolean validationEnabled) {
    this(new RouteSpec(), validationEnabled);
  }
  public RouteSpecBuilder(RouteSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RouteSpecBuilder(RouteSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RouteSpec(), validationEnabled);
  }
  public RouteSpecBuilder(RouteSpecFluent<?> fluent,RouteSpec instance) {
    this(fluent, instance, false);
  }
  public RouteSpecBuilder(RouteSpecFluent<?> fluent,RouteSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlternateBackends(instance.getAlternateBackends()); 
    fluent.withHost(instance.getHost()); 
    fluent.withPath(instance.getPath()); 
    fluent.withPort(instance.getPort()); 
    fluent.withSubdomain(instance.getSubdomain()); 
    fluent.withTls(instance.getTls()); 
    fluent.withTo(instance.getTo()); 
    fluent.withWildcardPolicy(instance.getWildcardPolicy()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RouteSpecBuilder(RouteSpec instance) {
    this(instance,false);
  }
  public RouteSpecBuilder(RouteSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlternateBackends(instance.getAlternateBackends()); 
    this.withHost(instance.getHost()); 
    this.withPath(instance.getPath()); 
    this.withPort(instance.getPort()); 
    this.withSubdomain(instance.getSubdomain()); 
    this.withTls(instance.getTls()); 
    this.withTo(instance.getTo()); 
    this.withWildcardPolicy(instance.getWildcardPolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RouteSpecFluent<?> fluent;
  Boolean validationEnabled;
  public RouteSpec build() {
    RouteSpec buildable = new RouteSpec(fluent.getAlternateBackends(),fluent.getHost(),fluent.getPath(),fluent.getPort(),fluent.getSubdomain(),fluent.getTls(),fluent.getTo(),fluent.getWildcardPolicy());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
